==> ionic-renderers-2.0.12-rc.4.tgz: package/src/controls/string/string-control.ts <==
import { Component } from '@angular/core';
import { isControl, JsonFormsState, RankedTester, rankWith } from '@jsonforms/core';
import { NgRedux } from '@angular-redux/store';
import { JsonFormsControl } from '@jsonforms/angular';

@Component({
    selector: 'jsonforms-string-control',
    template: `
      <ion-item [hidden]='hidden'>
          <ion-label floating>{{label}}</ion-label>
          <ion-label stacked *ngIf="error" color="error">{{error}}</ion-label>
          <ion-input
                  type="text"
                  (ionChange)="onChange($event)"
                  [value]="getValue()"
                  placeholder="{{ description }}"
                  [id]="id"
                  [formControl]="form"
                  [type]="getType()"
          >
          </ion-input>
      </ion-item>
  `
})
export class StringControlRenderer extends JsonFormsControl {
    constructor(ngRedux: NgRedux<JsonFormsState>) {
        super(ngRedux);
    }
    getValue = () => this.data || '';
    getType = (): string => {
        if (this.uischema.options && this.uischema.options.format) {
            return this.uischema.options.format;
        }
        if (this.scopedSchema && this.scopedSchema.format) {
            switch (this.scopedSchema.format) {
                case 'email': return 'email';
                case 'tel': return 'tel';
                default: return 'text';
            }
        }
        return 'text';
    }
}

export const stringControlTester: RankedTester = rankWith(
    1,
    isControl
);

==> ionic-renderers-2.1.0-rc.0.tgz: package/src/controls/string/string-control.ts <==
import { Component } from '@angular/core';
import { isStringControl, JsonFormsState, RankedTester, rankWith } from '@jsonforms/core';
import { NgRedux } from '@angular-redux/store';
import { JsonFormsControl } from '@jsonforms/angular';

@Component({
  selector: 'jsonforms-string-control',
  template: `
      <ion-item no-padding no-lines [hidden]='hidden'>
          <ion-label floating>{{label}}</ion-label>
          <ion-input
                  type="text"
                  (ionChange)="onChange($event)"
                  [value]="getValue()"
                  placeholder="{{ description }}"
                  [id]="id"
                  [formControl]="form"
                  [type]="getType()"
          >
          </ion-input>
          <ion-label stacked *ngIf="error" color="error">{{error}}</ion-label>
      </ion-item>
  `
})
export class StringControlRenderer extends JsonFormsControl {
    constructor(ngRedux: NgRedux<JsonFormsState>) {
        super(ngRedux);
    }
    getValue = () => this.data || '';
    getType = (): string => {
        if (this.uischema.options && this.uischema.options.format) {
            return this.uischema.options.format;
        }
        if (this.scopedSchema && this.scopedSchema.format) {
            switch (this.scopedSchema.format) {
                case 'email': return 'email';
                case 'tel': return 'tel';
                default: return 'text';
            }
        }
        return 'text';
    }
}

export const stringControlTester: RankedTester = rankWith(
    1,
    isStringControl
);
